Skip to contents

Fit multi-sample Gaussian Mixture Model (MSGMM)

Usage

MSGMM(
  files,
  K,
  usecols,
  init.means = NULL,
  init.files = NULL,
  init.size = 10000,
  seed = NULL,
  tol = 0.001,
  max.iter = 50,
  gamma = 1,
  lambda = 0.01,
  pooled = FALSE
)

Arguments

files

Character vector with CSV or FCS filenames

K

Integer specifying number of Gaussian components

usecols

Numeric or character vector specifying the columns to use

init.means

Initial values of means. (K-means used if not specified)

init.files

Character vector with CSV or FCS filenames to use for K-means

init.size

Number of data points to sample from each file for means initialization

seed

Random seed for subsampling during means initialization

tol

Convergence threshold for stopping criterion

max.iter

Maximum number of EM iterations

gamma

Starting value of component variance matrices

lambda

Regularization parameter for component covariance estimation

pooled

Logical flag to enable/disable multi-sample EM algorithm

Value

List of model parameters ("weights", "means", and "covariances")